# sdfspu
Some Python Utilities, by sdf

Utility functions and classes that are re-used across multiple projects.

## v 0.2
_Feb 2022_

- Started using [bump2version](https://github.com/c4urself/bump2version) tool
- [![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)

## pre 0.2
Collection was established in 2018 under a different repo.
